@@ -700,13 +700,25 @@ class MediaCloud(object):
         params = {'focal_sets_id': focal_sets_id}
         return self._queryForJson(self.V2_API_URL+'topics/{}/foci/list'.format(topics_id), params)['foci']
 
+    @mediacloud.error.deprecated
     def topicMediaMap(self, topics_id, **kwargs):
         params = {}
-        valid_params = ['color_field', 'num_media', 'include_weights', 'num_links_per_medium', 'snapshots_id',
-                        'foci_id', 'timespans_id', 'timespan_maps_id']
+        valid_params = ['color_field', 'num_media', 'include_weights', 'num_links_per_medium',
+                        'snapshots_id', 'foci_id', 'timespans_id']
         _validate_params(params, valid_params, kwargs)
         return self._query(self.V2_API_URL+'topics/{}/media/map'.format(topics_id), params).content
 
+    def topicMediaMapDownload(self, topics_id, timespans_maps_id, format):
+        """
+        New endpoint format for downloading auto-generated maps for each timespan in a topic.
+        :param topics_id:
+        :param timespans_maps_id: as reported by topicMediaMapList
+        :param format: 'svg' or 'gexf' (should match what topicMediaMapList reports for timespans_maps_id)
+        :return:
+        """
+        return self._query(self.V2_API_URL+'topics/{}/media/map'.format(topics_id),
+                           {'timespans_maps_id': timespans_maps_id, 'format': format}).content
+
     def topicMediaMapList(self, topics_id, **kwargs):
         params = {}
         valid_params = ['timespans_id']
